@@ -13,8 +13,8 @@ from typing import Any, Dict, Mapping, MutableMapping, Sequence, Tuple
 from markdown_it.common.normalize_url import unescape_string
 from markdown_it.token import Token
 
-from mdformat.renderer._default_renderers import DEFAULT_RENDERERS
-from mdformat.renderer._tree import RenderContext, RenderTreeNode
+from mdformat.renderer._context import DEFAULT_RENDERERS, RenderContext
+from mdformat.renderer._tree import RenderTreeNode
 from mdformat.renderer.typing import Postprocess
 
 LOGGER = logging.getLogger(__name__)
